==> thrio-1.7.5.tar.gz: ios/Classes/Module/ThrioModuleJsonDeserializer.m <==
// The MIT License (MIT)
//
// Copyright (c) 2020 foxsofter
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import "ThrioModule.h"
#import "ThrioModuleJsonDeserializer.h"
#import "ThrioNavigator+JsonDeserializers.h"

NS_ASSUME_NONNULL_BEGIN

@implementation ThrioModule (JsonDeserializer)

- (void)onJsonDeserializerRegister {
}

- (ThrioVoidCallback)registerJsonDeserializer:(id)deserializer
                                     forClass:(id)clazz {
    return [ThrioNavigator.jsonDeserializers registry:NSStringFromClass(clazz)
                                                value:deserializer];
}

@end

NS_ASSUME_NONNULL_END

==> thrio-2.0.4.tar.gz: ios/Classes/Module/ThrioModuleJsonDeserializer.m <==
// The MIT License (MIT)
//
// Copyright (c) 2020 foxsofter
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import "ThrioModule.h"
#import "ThrioModuleJsonDeserializer.h"
#import "ThrioModule+JsonDeserializers.h"

NS_ASSUME_NONNULL_BEGIN

@implementation ThrioModule (JsonDeserializer)

- (void)onJsonDeserializerRegister:(ThrioModuleContext *)moduleContext {
}

- (ThrioVoidCallback)registerJsonDeserializer:(id)deserializer
                                     forClass:(id)clazz {
    return [ThrioModule.jsonDeserializers registry:NSStringFromClass(clazz)
                                             value:deserializer];
}

@end

NS_ASSUME_NONNULL_END
